angular.module('sdb.services', [])
//本地存储服务
    .factory('LocalStorage', function ($window) {
        return {
            set: function (key, value) {
                $window.localStorage[key] = value;
                return 0;
            },
            get: function (key) {
                return $window.localStorage[key] || "";
            },
            remove: function (key) {
                $window.localStorage.removeItem(key);
                return 0;
            },
            clear: function () {
                localStorage.clear();
                return 0;
            }
        }
    })
    .factory('SysInfo', function ($q,$http,UILoad,BASE,LocalStorage) {
        var _app_version = "";
        var _app_download_url ="http://sdb.topjwd.com/s/download";
        var _wx_share_url = "http://sdb.topjwd.com/s/invitation/";
        return{
            //设置当前
            init_info: function (version) {
                _app_version = version;
                //初始化下载url
                $http({
                    method: 'post',
                    url: BASE.url + BASE.sys_info,
                    data:{id:4}
                })
                .success(function (res) {
                    _app_download_url = res.msg.content;
                })
                .error(function () {
                });
                //初始化在线css文件
                $http({
                    method: 'post',
                    url: BASE.url + BASE.sys_info,
                    data:{id:5}
                })
                .success(function (res) {
                    UILoad.load(res.msg.content);
                })
                .error(function () {
                });
            },
            get_app_version: function () {
                return _app_version;
            },
            set_local_version: function () {
                LocalStorage.set('local_version',_app_version);
                return null;
            },
            get_app_download_url: function () {
                return _app_download_url;
            },
            get_online_version: function () {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.last_sys_version
                })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            },
            show_splash: function () {
                var local_version = LocalStorage.get('local_version');
                return _app_version > local_version;
            },
            sys_info: function (c_id) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.sys_info,
                    data:{id:c_id}
                })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            }

        }
    })
    .service('UILoad', ['$document', '$q', '$timeout', function ($document, $q, $timeout) {

        var loaded = [];
        var promise = false;
        var deferred = $q.defer();

        /**
         * Chain loads the given sources
         * @param srcs array, script or css
         * @returns {*} Promise that will be resolved once the sources has been loaded.
         */
        this.load = function (srcs) {
            srcs = angular.isArray(srcs) ? srcs : srcs.split(/\s+/);
            var self = this;
            if(!promise){
                promise = deferred.promise;
            }
            angular.forEach(srcs, function(src) {
                promise = promise.then( function(){
                    return src.indexOf('.css') >=0 ? self.loadCSS(src) : self.loadScript(src);
                } );
            });
            deferred.resolve();
            return promise;
        };

        /**
         * Dynamically loads the given script
         * @param src The url of the script to load dynamically
         * @returns {*} Promise that will be resolved once the script has been loaded.
         */
        this.loadScript = function (src) {
            if(loaded[src]) return loaded[src].promise;

            var deferred = $q.defer();
            var script = $document[0].createElement('script');
            script.src = src;
            script.type = "text/javascript";
            script.onload = function (e) {
                $timeout(function () {
                    deferred.resolve(e);
                });
            };
            script.onerror = function (e) {
                $timeout(function () {
                    deferred.reject(e);
                });
            };
            $document[0].body.appendChild(script);
            loaded[src] = deferred;

            return deferred.promise;
        };

        /**
         * Dynamically loads the given CSS file
         * @param href The url of the CSS to load dynamically
         * @returns {*} Promise that will be resolved once the CSS file has been loaded.
         */
        this.loadCSS = function (href) {
            if(loaded[href]) return loaded[href].promise;

            var deferred = $q.defer();
            var style = $document[0].createElement('link');
            style.rel = 'stylesheet';
            style.type = 'text/css';
            style.href = href;
            style.onload = function (e) {
                $timeout(function () {
                    deferred.resolve(e);
                });
            };
            style.onerror = function (e) {
                $timeout(function () {
                    deferred.reject(e);
                });
            };
            $document[0].head.appendChild(style);
            loaded[href] = deferred;

            return deferred.promise;
        };
    }])
//游戏服务
    .factory('Game', function ($q, $http, BASE,Auth) {
        var g = {};
        g.qr_code = "";
        g.game_info = {};
        g.game_result = {money:""};
        g.str_postion = "";
        //通过url获取qrcode
        g.url2qrcode = function (url) {
            var reg = new RegExp("(^|&)p=([^&]*)(&|$)", "i");
            r = url.split("?")[1].match(reg);
            return r[2];
        };
        g.set_game_result = function(money){
            g.game_result.money = money;
            return null;
        };
        g.set_game_info = function (info) {
            g.game_info = info;
            return null;
        };
        g.decode_p = function (qr_cord) {
            g.qr_code = qr_cord;
            var defer = $q.defer();
            $http({
                method: 'post',
                url: BASE.url + BASE.decode_p,
                data: {p: qr_cord}
            })
            .success(function (res) {
                defer.resolve(res);
            })
            .error(function (err) {
                defer.reject(err);
            });
            return defer.promise;
        };
        g.set_postion = function (position) {
            g.str_postion = "{latitude:" +
                position.coords.latitude + ",longitude:" +
                position.coords.longitude + "}";
            return null;
        };
        //展示游戏
        g.show_prom = function (user) {
            //alert( g.qr_code);
            var defer = $q.defer();
            $http({
                method: 'post',
                url: BASE.url + BASE.show_prom,
                data: {
                    phone:user.phone,
                    token:user.token,
                    p: g.qr_code
                }
            })
            .success(function (res) {
                defer.resolve(res);
            })
            .error(function (err) {
                defer.reject(err);
            });
            return defer.promise;
        };
        g.open_bonus = function (excode) {
            //alert(g.qr_code);
            var defer = $q.defer();
            $http({
                method: 'post',
                url: BASE.url + BASE.open_bouns,
                data: {
                    phone:Auth.getUser().phone,
                    token:Auth.getUser().token,
                    p: g.qr_code,
                    excode: excode,
                    prom_id:g.game_info.prom_id,
                    position: g.str_postion
                }
            })
            .success(function (res) {
                defer.resolve(res);
            })
            .error(function (err) {
                defer.reject(err);
            });
            return defer.promise;
        };
        g.luck_list = function (data) {
            var defer = $q.defer();
            $http({
                method: 'post',
                url: BASE.url + BASE.luck_list,
                data: data
            })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
            return defer.promise;
        };
        g.user_add_dou = function (excode) {
            //alert(g.qr_code);
            var defer = $q.defer();
            $http({
                method: 'post',
                url: BASE.url + BASE.user_add_dou,
                data: {
                    phone:Auth.getUser().phone,
                    token:Auth.getUser().token,
                    p: g.qr_code,
                    excode: excode,
                    prom_id:g.game_info.prom_id,
                    position: g.str_postion
                }
            })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
            return defer.promise;
        };
        return g;
    })
    //我的奖励
    .factory('MyAwards', function ($q, $http, BASE, Auth) {
        return{
            check_unopen: function () {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.check_unopen,
                    data: {
                        phone: Auth.getUser().phone,
                        token: Auth.getUser().token
                    }
                })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            },
            my_count: function () {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.my_count,
                    data: {
                        phone: Auth.getUser().phone,
                        token: Auth.getUser().token
                    }
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            },
            input_invitation_code: function (code) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.input_invitation_code,
                    data: {
                        phone: Auth.getUser().phone,
                        token: Auth.getUser().token,
                        code:code
                    }
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            },
            add_feedback: function (data) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.add_feedback,
                    data: data
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            }
        }
    })
    //收藏
    .factory('MyFavorite', function ($q, $http, BASE, Auth) {
        return{
            is_fav: function (prod_id) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.is_fav,
                    data: {
                        phone: Auth.getUser().phone,
                        token: Auth.getUser().token,
                        prod_id: prod_id
                    }
                })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            },
            set_fav: function(prod_id,state){
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.set_fav,
                    data: {
                        phone: Auth.getUser().phone,
                        token: Auth.getUser().token,
                        prod_id: prod_id,
                        state:state
                    }
                })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            },
            my_fav_list:function(){
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.my_fav_list,
                    data: {
                        phone: Auth.getUser().phone,
                        token: Auth.getUser().token
                    }
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            }
        }
    })
    //我的优惠券
    .factory('Mycoupons', function ($q, $http, BASE) {
        return{
            user_coupon_list: function (data) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.user_coupon_list,
                    data: data
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            },
            award_detail:function (award_id) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.award_detail,
                    data: {id:award_id}
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            }
        }
    })
    //我的钱包
    .factory('Mywallet', function ($q, $http, BASE, Auth) {
        return{
            money_detail: function (conf) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.money_detail,
                    data: {
                        phone: Auth.getUser().phone,
                        token: Auth.getUser().token,
                        page_size: conf.page_size,
                        page_index: conf.page_index
                    }
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            },
            check_alipay: function(){
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.check_alipay,
                    data: {
                        phone: Auth.getUser().phone,
                        token: Auth.getUser().token
                    }
                })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            },
            user_withdraw: function (alipay_id,alipay_name,money) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.user_withdraw,
                    data: {
                        phone: Auth.getUser().phone,
                        token: Auth.getUser().token,
                        alipay_id:alipay_id,
                        alipay_name:alipay_name,
                        money:money
                    }
                })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            }
        }
    })
    //品牌服务
    .factory('Brand', function ($q, $http, BASE) {
        return{
            brand_list: function (data) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.brand_list,
                    data:data
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            },
            brand_products:function (data) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.brand_products,
                    data:data
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            }
        }
    })
    //消息服务
    .factory('Msg', function ($q, $http, BASE) {
        var _msglist = [];
        var _msgcount_unread = 0;
        return{
            set_msglist: function (msglist) {
                _msglist = msglist;
                return null;
            },
            get_msginfo: function (id) {
                return _msglist[id];
            },
            has_message:function (data) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.has_message,
                    data:data
                })
                .success(function (res) {
                    _msgcount_unread = res.msg;
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            },
            user_message:function (data) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.user_message,
                    data:data
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            },
            message_has_read:function (msg_id) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.message_has_read,
                    data:{msg_id:msg_id}
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            },
            message_delete: function (msg_id) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.message_delete,
                    data:{msg_id:msg_id}
                })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            }
        }
    })
    //搜索服务
    .factory('Search', function ($q, $http, BASE) {
        return{
            hot_search_list:function () {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.hot_search_list
                })
                    .success(function (res) {
                            defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            },
            get_result:function (data) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.get_result,
                    data:data
                })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            }
        }
    })
    //广告活动，banner
    .factory('AdpromList', function ($q, $http, BASE) {
        return{
            ad_prom_list: function (data) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.ad_prom_list,
                    data: data
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            },
            ad_prom_detail: function (adprom_id) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.ad_prom_detail,
                    data: {id:adprom_id}
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            }
        }
    })
//产品服务
    .factory('Product', function ($q, $http, BASE) {
        var cate_select = {cate_id:"0",cate_level:"1",page_size:"10",page_index:0,desc_col:"average"};
        var _category ={};
        return {
            select_cate: function (level, id) {
                cate_select.cate_id = id;
                cate_select.cate_level = level;
                return null;
            },
            product_list_hot: function (data) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.product_list,
                    data: data
                })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            },
            product_records: function (pid) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.product_records,
                    data: {prod_id: pid}
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            },
            product_list_by_cate_id: function (data) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.product_list_by_cate_id,
                    data: data
                })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            },
            prod_info_short: function (pid) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.product_short,
                    data: {prod_id: pid}
                })
                .success(function (res) {
                    defer.resolve(res.msg);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            },
            product_detail: function (pid) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.product_detail,
                    data: {prod_id: pid}
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            },
            get_category: function () {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.product_category
                })
                    .success(function (res) {
                        _category = res.msg;
                        defer.resolve(res.msg);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            }
        }
    })
//活动服务
    .factory('Promotion', function ($q, $http, BASE) {
        var _promlist = {};
        return{
            promlist_short: function (pid) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.prom_short,
                    data: {prod_id: pid}
                })
                    .success(function (res) {
                        _promlist = res.msg;
                        defer.resolve(res.msg);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            }
        }
    })
    //评论服务
    .factory('Comment', function ($q, $http, BASE) {
        var _commentlist ={};
        var page_index_plh = 0;
        return{
            comment_list_short: function (pid) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.comment_list,
                    data: {prod_id:pid,page_size: "2", page_index: page_index_plh, desc_col: "score"}
                })
                .success(function (res) {
                        if(res.code == 1)
                            defer.resolve(res.msg);
                        else
                            defer.resolve(null);

                        //page_index_plh++;
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            },
            comment_list: function (post_conf) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.comment_list,
                    data: post_conf
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            },
            comment_add: function (data) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.comment_add,
                    data:data
                })
                .success(function (res) {
                    defer.resolve(res);
                    //page_index_plh++;
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            }
        }
    })
//登录验证服务
    .factory('Auth', function ($q, $http, BASE, SysInfo,LocalStorage) {
        var _user = {
            phone: LocalStorage.get('user_phone'),
            token: LocalStorage.get('user_token')
        };
        var _user_meta ={
            nickname:LocalStorage.get('user_meta_nickname'),
            img_path:LocalStorage.get('user_meta_img_path'),
            phone:LocalStorage.get('user_meta_phone'),
            sex:LocalStorage.get('user_meta_sex'),
            my_code:LocalStorage.get('user_meta_my_code'),
            is_updated_nickname:LocalStorage.get('user_meta_is_updated_nickname'),
            default_area:LocalStorage.get('user_meta_default_area')
        };
        return {
            //发送验证短信
            send_sms: function (phone) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.send_sms,
                    data: {p: phone}
                })
                    .success(function (res) {
                        defer.resolve(res);
                    })
                    .error(function (err) {
                        defer.reject(err);
                    });
                return defer.promise;
            },
            //用户登录
            login: function (phone, code) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.user_login,
                    data: {p: phone, c: code}
                })
                .success(function (res) {
                    if (res.code == 1) {
                        _user.phone = res.msg.phone;
                        _user.token = res.msg.token;
                        _user_meta = res.msg.meta;
                        LocalStorage.set('user_phone', res.msg.phone);
                        LocalStorage.set('user_token', res.msg.token);
                        LocalStorage.set('user_meta_img_path', res.msg.meta.img_path);
                        LocalStorage.set('user_meta_is_updated_nickname', res.msg.meta.is_updated_nickname);
                        LocalStorage.set('user_meta_nickname', res.msg.meta.nickname);
                        LocalStorage.set('user_meta_phone', res.msg.meta.phone);
                        LocalStorage.set('user_meta_sex', res.msg.meta.sex);
                        LocalStorage.set('user_meta_my_code', res.msg.meta.my_code);
                        LocalStorage.set('user_meta_default_area', res.msg.meta.default_area);
                        LocalStorage.set('user_login_time', (new Date()).getTime());
                        LocalStorage.set('user_expires_time', "30 days");
                    }
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            },
            //用户登出
            logout: function () {
                LocalStorage.clear();
                SysInfo.set_local_version();
                _user = {};
                return null;
            },
            //获取用户信息
            user_meta_info: function () {
                return _user_meta.nickname ? _user_meta : null;
            },
            //更新用户信息
            update_user_info: function (data) {
                var defer = $q.defer();
                $http({
                    method: 'post',
                    url: BASE.url + BASE.update_user_info,
                    data: data
                })
                .success(function (res) {
                    defer.resolve(res);
                })
                .error(function (err) {
                    defer.reject(err);
                });
                return defer.promise;
            },
            set_user_info: function (data) {
                _user_meta = data;
                LocalStorage.set('user_meta_img_path', _user_meta.img_path);
                LocalStorage.set('user_meta_my_code', _user_meta.my_code);
                LocalStorage.set('user_meta_is_updated_nickname', _user_meta.is_updated_nickname);
                LocalStorage.set('user_meta_nickname', _user_meta.nickname);
                LocalStorage.set('user_meta_phone', _user_meta.phone);
                LocalStorage.set('user_meta_sex', _user_meta.sex);
                LocalStorage.set('user_meta_default_area', _user_meta.default_area);
                return null;
            },
            //用户是否登录
            islogin: function () {
                return _user.phone ? true : false;
            },
            check_user: function () {
                if(_user.phone){
                    $http({
                        method: 'post',
                        url: BASE.url + BASE.check_user,
                        data: _user
                    })
                    .success(function (res) {
                        if(res.code != 1){
                            LocalStorage.clear();
                            LocalStorage.set_version();
                            _user = {};
                        }
                    })
                    .error(function () {

                    });
                }
            },
            //如果存在用户，得到用户信息
            getUser: function () {
                return _user.phone ? _user : null;
            }
        };
    });
